import scrapy

"""
USO:

scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=2 -a day=21
"""

import re

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class NoticiasItem(scrapy.Item):
    title = scrapy.Field()
    text = scrapy.Field()
    date = scrapy.Field()
    location = scrapy.Field()
    author = scrapy.Field()
    topic = scrapy.Field()
    url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
	name = 'noticias'
	def start_requests(self):
		self.section = ''
		self.page = 0
		self.count = 0
		self.found = False
		self.year = getattr(self, 'year', None)
		self.month = getattr(self, 'month', None)
		self.day = getattr(self, 'day', None)
		self.baseURL = 'http://jornadabc.mx'
		section_list = ['baja-california', 'chihuahua', 'mexico', 'mundo'
						'cultura', 'espectaculos', 'deportes']
		
		for section in section_list:
			self.section = section
			self.page = 0
			self.count = 0
			page = -1
			while True:
				if ( self.found ):
					break
				page += 1
				yield scrapy.Request(url=self.baseURL+'/seccion/'+section+'?page='+str(page), callback=self.parse, dont_filter=True)
			
			self.page -= self.count
			if ( self.page > 0 ):
				self.page -= 1
			
			for pag in range(self.page, self.page+25):
				yield scrapy.Request(url=self.baseURL+'/seccion/'+section+'?page='+str(pag), callback=self.parse_page, dont_filter=True)				



	def parse(self, response):
		if ( self.section == 'espectaculos' or self.section == 'deportes' ):
			path = '//*[@class="region region-soft-first"]'
		else:
			path = '//*[@class="region region-hard-first"]'

		for link in response.xpath(path).css('div.views-row').xpath('./*[@class="views-field views-field-title"]/span[@class="field-content"]/a/@href').extract():
			link_date = link[:link.rfind('/')][link[:link.rfind('/')].rfind('/')+1:]   # filtra la fecha del link
			if ( link_date == self.day.zfill(2)+'-'+self.month.zfill(2)+'-'+self.year ):
				self.page = int(response.url[response.url.rfind('=')+1:])
				self.count += 1
				self.found = True
				break


	def parse_page(self, response):
		if ( self.section == 'espectaculos' or self.section == 'deportes' ):
			path = '//*[@class="region region-soft-first"]'
		else:
			path = '//*[@class="region region-hard-first"]'

		for link in response.xpath(path).css('div.views-row').xpath('./*[@class="views-field views-field-title"]/span[@class="field-content"]/a/@href').extract():
			link_date = link[:link.rfind('/')][link[:link.rfind('/')].rfind('/')+1:]   # filtra la fecha del link
			if ( link_date == self.day.zfill(2)+'-'+self.month.zfill(2)+'-'+self.year ):
				yield scrapy.Request(url=self.baseURL+link, callback=self.parse_item)


	def parse_item(self, response):
		item = NoticiasItem()
		text = ''
		item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
		title = response.xpath('//*[@class="block-content"]/h1/a/text()').extract()
		if ( len(title) > 0 ):
			item['title'] = title[0]
		else:
			item['title'] = response.xpath('//*[@class="block-content"]/h1/text()').extract_first()

		item['topic'] = response.xpath('//span[@class="section"]/text()').extract_first()
		for paragraph in response.xpath('//*[@class="field-item even"]/p/text()').extract():
			text += paragraph
		item['text'] = text
		item['url'] = response.url
		# print item['title']
		yield item
